@@ -11,7 +11,8 @@
 #include "structdef.h"
 
 #include <DApplication>
-#include <DApplicationHelper>
+#include <DGuiApplicationHelper>
+#include <DPaletteHelper>
 #include <DComboBox>
 #include <DCommandLinkButton>
 #include <DFileDialog>
@@ -29,6 +30,9 @@
 #include <QVBoxLayout>
 #include <QResizeEvent>
 #include <QPainterPath>
+#include <QLoggingCategory>
+
+Q_LOGGING_CATEGORY(logFilter, "org.deepin.log.viewer.filter")
 
 #define BUTTON_WIDTH_MIN 68
 #define BUTTON_HEIGHT_MIN 36
@@ -48,17 +52,24 @@ FilterContent::FilterContent(QWidget *parent)
     , m_curBtnId(ALL)
     , m_curLvCbxId(INF)
 {
+    qCDebug(logFilter) << "FilterContent constructor start";
+
     initUI();
     initConnections();
 }
 
-FilterContent::~FilterContent() {}
+FilterContent::~FilterContent()
+{
+    qCDebug(logFilter) << "FilterContent destructor";
+}
 
 /**
  * @brief FilterContent::initUI 初始化界面
  */
 void FilterContent::initUI()
 {
+    qCDebug(logFilter) << "Initializing filter UI components";
+
     QVBoxLayout *vLayout = new QVBoxLayout(this);
     // set period info
     hLayout_period = new QHBoxLayout;
@@ -104,7 +115,7 @@ void FilterContent::initUI()
     lvTxt->setAccessibleName(DApplication::translate("Label", "Level:  "));
     lvTxt->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     cbx_lv = new LogCombox(this);
-    cbx_lv->view()->setAccessibleName("combobox_level_view");
+    //cbx_lv->view()->setAccessibleName("combobox_level_view");
     cbx_lv->setMinimumWidth(LEVEL_COMBO_WIDTH);
     cbx_lv->addItems(QStringList() << DApplication::translate("ComboBox", "All")
                      << DApplication::translate("ComboBox", "Emergency")
@@ -125,7 +136,7 @@ void FilterContent::initUI()
     dnflvTxt->setAccessibleName("dnf" + DApplication::translate("Label", "Level:  "));
     dnflvTxt->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     cbx_dnf_lv = new LogCombox(this);
-    cbx_dnf_lv->view()->setAccessibleName("combobox_dnflevel_view");
+    //cbx_dnf_lv->view()->setAccessibleName("combobox_dnflevel_view");
     cbx_dnf_lv->setMinimumWidth(198);
     cbx_dnf_lv->addItem(DApplication::translate("ComboBox", "All"), DNFLVALL);
     cbx_dnf_lv->addItem(DApplication::translate("ComboBox", "Super critical"), SUPERCRITICAL);
@@ -143,7 +154,7 @@ void FilterContent::initUI()
     QHBoxLayout *hLayout_app = new QHBoxLayout;
     appTxt = new DLabel(DApplication::translate("Label", "Application:"), this);
     cbx_app = new LogCombox(this);
-    cbx_app->view()->setAccessibleName("combobox_app_view");
+    //cbx_app->view()->setAccessibleName("combobox_app_view");
 
     cbx_app->setMinimumWidth(160);
     hLayout_app->addWidget(appTxt);
@@ -155,7 +166,7 @@ void FilterContent::initUI()
     QHBoxLayout *hLayout_submodule = new QHBoxLayout;
     submoduleTxt = new DLabel(DApplication::translate("Label", "Submodule:"), this);
     cbx_submodule = new LogCombox(this);
-    cbx_submodule->view()->setAccessibleName("combobox_submodule_view");
+    //cbx_submodule->view()->setAccessibleName("combobox_submodule_view");
 
     cbx_submodule->setMinimumWidth(143);
     hLayout_submodule->addWidget(submoduleTxt);
@@ -168,7 +179,7 @@ void FilterContent::initUI()
     QHBoxLayout *hLayout_status = new QHBoxLayout;
     statusTxt = new DLabel(DApplication::translate("Label", "Status:"), this);
     cbx_status = new LogCombox(this);
-    cbx_status->view()->setAccessibleName("combobox_status_view");
+    //cbx_status->view()->setAccessibleName("combobox_status_view");
     cbx_status->setMinimumWidth(120);
     cbx_status->addItems(QStringList() << DApplication::translate("ComboBox", "All") << "OK"
                          << "Failed");
@@ -181,7 +192,7 @@ void FilterContent::initUI()
     QHBoxLayout *hLayout_type = new QHBoxLayout;
     typeTxt = new DLabel(DApplication::translate("Label", "Event Type:"), this);
     typeCbx = new LogCombox(this);
-    typeCbx->view()->setAccessibleName("combobox_eventtype_view");
+    //typeCbx->view()->setAccessibleName("combobox_eventtype_view");
     typeCbx->setMinimumWidth(120);
     typeCbx->addItems(QStringList() << DApplication::translate("ComboBox", "All")
                       << DApplication::translate("ComboBox", "Login")
@@ -219,6 +230,7 @@ void FilterContent::initUI()
     vLayout->addLayout(hLayout_all);
     vLayout->setSpacing(16);
     this->setLayout(vLayout);
+    qCDebug(logFilter) << "Setting initial selector visibility";
     setSelectorVisible(true, false, false, true, false);
     m_currentType = JOUR_TREE_DATA;
     //设置初始筛选选项
@@ -238,7 +250,13 @@ void FilterContent::initUI()
  */
 void FilterContent::initConnections()
 {
+    qCDebug(logFilter) << "Initializing signal-slot connections";
+
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     connect(m_btnGroup, SIGNAL(buttonClicked(int)), this, SLOT(slot_buttonClicked(int)));
+#else
+    connect(m_btnGroup, &QButtonGroup::idClicked, this, &FilterContent::slot_buttonClicked);
+#endif
     connect(exportBtn, &DPushButton::clicked, this, &FilterContent::slot_exportButtonClicked);
     connect(cbx_dnf_lv, SIGNAL(currentIndexChanged(int)), this, SLOT(slot_cbxDnfLvIdxChanged(int)));
 
@@ -255,6 +273,7 @@ void FilterContent::initConnections()
  */
 void FilterContent::shortCutExport()
 {
+    qCDebug(logFilter) << "Processing shortcut export request";
     QString itemData = m_curTreeIndex.data(ITEM_DATE_ROLE).toString();
     bool canExport = true;
     if (exportBtn) {
@@ -270,6 +289,7 @@ void FilterContent::shortCutExport()
  */
 void FilterContent::setAppComboBoxItem()
 {
+    qCDebug(logFilter) << "Refreshing application combo box items";
     //必须先disconnect变动值的信号槽,因为改变下拉选项会几次触发currentIndexChanged信号,这不是我们想要的
     disconnect(cbx_app, SIGNAL(currentIndexChanged(int)), this, SLOT(slot_cbxAppIdxChanged(int)));
     cbx_app->clear();
@@ -329,6 +349,11 @@ void FilterContent::setSubmodulesComboBoxItem(const QString &app)
 void FilterContent::setSelectorVisible(bool lvCbx, bool appListCbx, bool statusCbx, bool period,
                                        bool needMove, bool typecbx, bool dnfCbx, bool auditCbx)
 {
+    qCDebug(logFilter) << "Updating selector visibility - Level:" << lvCbx
+                       << "App:" << appListCbx << "Status:" << statusCbx
+                       << "Period:" << period << "NeedMove:" << needMove
+                       << "Type:" << typecbx << "DNF:" << dnfCbx << "Audit:" << auditCbx;
+
     //先不立马更新界面,等全部更新好控件状态后再更新界面,否则会导致界面跳动
     setUpdatesEnabled(false);
     lvTxt->setVisible(lvCbx);
@@ -461,7 +486,7 @@ void FilterContent::paintEvent(QPaintEvent *event)
     QPen oldPen = painter.pen();
     //设置画笔颜色角色,根据主题变色
     painter.setRenderHint(QPainter::Antialiasing);
-    DPalette pa = DApplicationHelper::instance()->palette(this);
+    DPalette pa = DPaletteHelper::instance()->palette(this);
     painter.setBrush(QBrush(pa.color(DPalette::Base)));
     QColor penColor = pa.color(DPalette::FrameBorder);
     //设置透明度
@@ -621,12 +646,15 @@ void FilterContent::updateWordWrap()
         QFont standFont = m_allBtn->font();
         QFont standFontBig = standFont;
         standFont.setPointSizeF(13.5);
-        periodLabel->setText(QFontMetrics(periodLabel->font()).elidedText(DApplication::translate("Label", "Period:"), Qt::ElideRight, 1 + QFontMetrics(periodLabel->font()).width(DApplication::translate("Label", "Period:"))));
-        m_todayBtn->setText(QFontMetrics(m_todayBtn->font()).elidedText(DApplication::translate("Button", "Today"), Qt::ElideRight, 1 + QFontMetrics(standFont).width(DApplication::translate("Button", "Today"))));
-        m_threeDayBtn->setText(QFontMetrics(m_threeDayBtn->font()).elidedText(DApplication::translate("Button", "3 days"), Qt::ElideRight, 1 + QFontMetrics(standFont).width(DApplication::translate("Button", "3 days"))));
-        m_lastWeekBtn->setText(QFontMetrics(m_lastWeekBtn->font()).elidedText(DApplication::translate("Button", "1 week"), Qt::ElideRight, 1 + QFontMetrics(standFont).width(DApplication::translate("Button", "1 week"))));
-        m_lastMonthBtn->setText(QFontMetrics(m_lastMonthBtn->font()).elidedText(DApplication::translate("Button", "1 month"), Qt::ElideRight, 1 + QFontMetrics(standFont).width(DApplication::translate("Button", "1 month"))));
-        m_threeMonthBtn->setText(QFontMetrics(m_threeMonthBtn->font()).elidedText(DApplication::translate("Button", "3 months"), Qt::ElideRight, 1 + QFontMetrics(standFont).width(DApplication::translate("Button", "3 months"))));
+        QFontMetrics periodMetrics(periodLabel->font());
+        QFontMetrics metrics(standFont);
+
+        periodLabel->setText(QFontMetrics(periodLabel->font()).elidedText(DApplication::translate("Label", "Period:"), Qt::ElideRight, 1 + periodMetrics.horizontalAdvance(DApplication::translate("Label", "Period:"))));
+        m_todayBtn->setText(QFontMetrics(m_todayBtn->font()).elidedText(DApplication::translate("Button", "Today"), Qt::ElideRight, 1 + metrics.horizontalAdvance(DApplication::translate("Button", "Today"))));
+        m_threeDayBtn->setText(QFontMetrics(m_threeDayBtn->font()).elidedText(DApplication::translate("Button", "3 days"), Qt::ElideRight, 1 + metrics.horizontalAdvance(DApplication::translate("Button", "3 days"))));
+        m_lastWeekBtn->setText(QFontMetrics(m_lastWeekBtn->font()).elidedText(DApplication::translate("Button", "1 week"), Qt::ElideRight, 1 + metrics.horizontalAdvance(DApplication::translate("Button", "1 week"))));
+        m_lastMonthBtn->setText(QFontMetrics(m_lastMonthBtn->font()).elidedText(DApplication::translate("Button", "1 month"), Qt::ElideRight, 1 + metrics.horizontalAdvance(DApplication::translate("Button", "1 month"))));
+        m_threeMonthBtn->setText(QFontMetrics(m_threeMonthBtn->font()).elidedText(DApplication::translate("Button", "3 months"), Qt::ElideRight, 1 + metrics.horizontalAdvance(DApplication::translate("Button", "3 months"))));
     }  else  {
         periodLabel->setText(DApplication::translate("Label", "Period:"));
         m_allBtn->setText(DApplication::translate("Button", "All"));
