@@ -4,6 +4,7 @@
 
 #include "logapplicationhelper.h"
 #include "utils.h"
+#include "qtcompat.h"
 
 #include <QDebug>
 #include <QDir>
@@ -198,7 +199,7 @@ void LogApplicationHelper::initCustomLog()
     if(m_pDConfig->keyList().contains("specialComType"))
         Utils::specialComType = m_pDConfig->value("specialComType").toInt();
 #endif
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     //初始化gsetting配置
     if (!m_pGSettings) {
         if (QGSettings::isSchemaInstalled(GSETTING_APPID.toUtf8())) {
@@ -226,6 +227,7 @@ void LogApplicationHelper::initCustomLog()
             qCWarning(logAppHelper) << "cannot find gsettings config file";
         }
     }
+#endif
 }
 
 /**
@@ -236,88 +238,98 @@ void LogApplicationHelper::createDesktopFiles()
     m_desktop_files.clear();
     m_en_trans_map.clear();
 
-    //在该目录下遍历所有desktop文件
-    QString path = "/usr/share/applications";
-    QDir dir(path);
-    if (!dir.exists())
-        return;
+    // 定义要搜索的目录列表
+    QStringList searchPaths = {
+        "/usr/share/applications",
+        "/var/lib/linglong/entries/share/applications"
+    };
 
-    QStringList fileInfoList = dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
-    QStringList tempDesktopFiles;
     QStringList regStr {"deepin-", "dde-", "org.deepin", "com.deepin", "uos-"};
-    for (QString desktop : fileInfoList) {
-        //需要符合以deepin或者dde开头的应用
-        for (auto &it : regStr) {
-            if (desktop.contains(it)) {
-                tempDesktopFiles.append(desktop);
-                break;
-            }
-        }
-    }
-    for (QString var : tempDesktopFiles) {
-        QString filePath = path + "/" + var;
-        QFile fi(filePath);
-        if (!fi.open(QIODevice::ReadOnly))
+    
+    // 遍历所有搜索目录
+    for (const QString &path : searchPaths) {
+        QDir dir(path);
+        if (!dir.exists())
             continue;
-        bool isDeepin = false;
-        bool isGeneric = false;
-        bool isName = false;
-        bool canDisplay = true;
-        while (!fi.atEnd()) {
-            QString lineStr = fi.readLine();
-            lineStr.replace("\n", "");
 
-            if (lineStr.startsWith("GenericName", Qt::CaseInsensitive) && !isGeneric) {
-                isGeneric = true;
-            }
-            if (lineStr.startsWith("Name", Qt::CaseInsensitive) && !isName) {
-                isName = true;
-            }
-            if (lineStr.startsWith("Hidden")) {
-                QStringList hiddenList = lineStr.split("=", QString::SkipEmptyParts);
-                if (hiddenList.value(1, "") == "true") {
-                    canDisplay = false;
+        QStringList fileInfoList = dir.entryList(QDir::Files | QDir::NoDotAndDotDot);
+        QStringList tempDesktopFiles;
+        
+        for (QString desktop : fileInfoList) {
+            //需要符合以deepin或者dde开头的应用
+            for (auto &it : regStr) {
+                if (desktop.contains(it)) {
+                    tempDesktopFiles.append(desktop);
+                    break;
                 }
             }
-            QString currentDesktop(qgetenv("XDG_CURRENT_DESKTOP"));
-            if (lineStr.startsWith("OnlyShowIn")) {
-                QString onlyShowValue = lineStr.split("=", QString::SkipEmptyParts).value(1, "");
-                if (onlyShowValue.contains(currentDesktop)) {
-                    continue;
-                } else {
-                    canDisplay = false;
-                }
-            }
-
-            if (lineStr.startsWith("NotShowIn")) {
-                QStringList notShowInList = lineStr.split("=", QString::SkipEmptyParts).value(1, "").split(";", QString::SkipEmptyParts);
-                if (std::any_of(notShowInList.begin(), notShowInList.end(), [currentDesktop](const auto & data) {
-                return data == currentDesktop;
-            })) {
-                    canDisplay = false;
-                }
-            }
-
-            if (!lineStr.contains("X-Deepin-Vendor", Qt::CaseInsensitive)) {
-                continue;
-            }
-
-            QStringList _x_vendor_list = lineStr.split("=", QString::SkipEmptyParts);
-            if (_x_vendor_list.count() != 2) {
-                continue;
-            }
-
-            QString rval = _x_vendor_list[1];
-            if (0 == rval.compare("deepin", Qt::CaseInsensitive)) {
-                isDeepin = true;
-                break;
-            }
         }
-        fi.close();
-        //转换插入应用包名和应用显示文本到数据结构
-        if (canDisplay) {
-            m_desktop_files.append(var);
-            generateTransName(filePath, var.split(QDir::separator()).last(), isDeepin, isGeneric, isName);
+        
+        for (QString var : tempDesktopFiles) {
+            QString filePath = path + "/" + var;
+            QFile fi(filePath);
+            if (!fi.open(QIODevice::ReadOnly))
+                continue;
+            bool isDeepin = false;
+            bool isGeneric = false;
+            bool isName = false;
+            bool canDisplay = true;
+            while (!fi.atEnd()) {
+                QString lineStr = fi.readLine();
+                lineStr.replace("\n", "");
+
+                if (lineStr.startsWith("GenericName", Qt::CaseInsensitive) && !isGeneric) {
+                    isGeneric = true;
+                }
+                if (lineStr.startsWith("Name", Qt::CaseInsensitive) && !isName) {
+                    isName = true;
+                }
+                if (lineStr.startsWith("Hidden")) {
+                    QStringList hiddenList = lineStr.split("=", SKIP_EMPTY_PARTS);
+                    if (hiddenList.value(1, "") == "true") {
+                        canDisplay = false;
+                    }
+                }
+                QString currentDesktop(qgetenv("XDG_CURRENT_DESKTOP"));
+                if (lineStr.startsWith("OnlyShowIn")) {
+                    QString onlyShowValue = lineStr.split("=", SKIP_EMPTY_PARTS).value(1, "");
+                    if (onlyShowValue.contains(currentDesktop)) {
+                        continue;
+                    } else {
+                        canDisplay = false;
+                    }
+                }
+
+                if (lineStr.startsWith("NotShowIn")) {
+                    QStringList notShowInList = lineStr.split("=", SKIP_EMPTY_PARTS).value(1, "").split(";", SKIP_EMPTY_PARTS);
+                    if (std::any_of(notShowInList.begin(), notShowInList.end(), [currentDesktop](const auto & data) {
+                    return data == currentDesktop;
+                })) {
+                        canDisplay = false;
+                    }
+                }
+
+                if (!lineStr.contains("X-Deepin-Vendor", Qt::CaseInsensitive)) {
+                    continue;
+                }
+
+                QStringList _x_vendor_list = lineStr.split("=", SKIP_EMPTY_PARTS);
+                if (_x_vendor_list.count() != 2) {
+                    continue;
+                }
+
+                QString rval = _x_vendor_list[1];
+                if (0 == rval.compare("deepin", Qt::CaseInsensitive)) {
+                    isDeepin = true;
+                    break;
+                }
+            }
+            fi.close();
+            //转换插入应用包名和应用显示文本到数据结构
+            if (canDisplay) {
+                m_desktop_files.append(var);
+                generateTransName(filePath, var.split(QDir::separator()).last(), isDeepin, isGeneric, isName);
+            }
         }
     }
 }
@@ -426,7 +438,7 @@ void LogApplicationHelper::generateTransName(const QString &path, const QString
                 continue;
         }
 
-        QStringList gNameList = lineStr.split("=", QString::SkipEmptyParts);
+        QStringList gNameList = lineStr.split("=", SKIP_EMPTY_PARTS);
         if (gNameList.count() != 2)
             continue;
 
@@ -479,6 +491,7 @@ void LogApplicationHelper::loadAppLogConfigsByJson()
         qCWarning(logAppHelper) << QString("%1 does not exist.").arg(APP_LOG_CONFIG_PATH);
         return;
     }
+    qCDebug(logAppHelper) << "Loading app log configs from:" << APP_LOG_CONFIG_PATH;
 
     dir.setFilter(QDir::Files);
     dir.setNameFilters(QStringList() << "*.json");
@@ -494,6 +507,7 @@ void LogApplicationHelper::loadAppLogConfigsByJson()
         QJsonParseError parseError;
         QJsonDocument document = QJsonDocument::fromJson(data, &parseError);
         if (parseError.error == QJsonParseError::NoError) {
+            qCDebug(logAppHelper) << "Successfully parsed JSON config file:" << fi.fileName();
             if (document.isObject()) {
                 QJsonObject object = document.object();
 
@@ -756,14 +770,18 @@ QDateTime LogApplicationHelper::getLastReportTime()
 #ifdef DTKCORE_CLASS_DConfigFile
     time = m_pDConfig->value(COREDUMP_REPORT_TIME);
 #else
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (m_pGSettings) {
         time = m_pGSettings->get(COREDUMP_REPORT_TIME_GSETTING);
     }
+#endif
 #endif
 
     if (time.isValid()) {
+        qCDebug(logAppHelper) << "Got last report time from config:" << time.toString();
         return QDateTime::fromString(time.toString(), "yyyy-MM-dd hh:mm:ss");
     }
+    qCDebug(logAppHelper) << "No valid last report time found in config";
 
     return QDateTime();
 }
@@ -771,13 +789,16 @@ QDateTime LogApplicationHelper::getLastReportTime()
 void LogApplicationHelper::saveLastRerportTime(const QDateTime &date)
 {
     QString str = date.toString("yyyy-MM-dd hh:mm:ss");
+    qCDebug(logAppHelper) << "Saving last report time:" << str;
 
 #ifdef DTKCORE_CLASS_DConfigFile
     m_pDConfig->setValue(COREDUMP_REPORT_TIME, str);
 #else
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (m_pGSettings)
         m_pGSettings->set(COREDUMP_REPORT_TIME_GSETTING, str);
 #endif
+#endif
 }
 
 int LogApplicationHelper::getMaxReportCoredump()
@@ -787,9 +808,11 @@ int LogApplicationHelper::getMaxReportCoredump()
 #ifdef DTKCORE_CLASS_DConfigFile
     value = m_pDConfig->value(COREDUMP_REPORT_MAX);
 #else
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (m_pGSettings) {
         value = m_pGSettings->get(COREDUMP_REPORT_MAX_GSETTING);
     }
+#endif
 #endif
 
     qCWarning(logAppHelper) << "coredump report max:" << value.toInt();
