@@ -43,16 +43,19 @@ LogBackend *LogBackend::m_staticbackend = nullptr;
 
 LogBackend *LogBackend::instance(QObject *parent)
 {
+    qCDebug(logBackend) << "Getting LogBackend instance";
     if (parent != nullptr && m_staticbackend == nullptr) {
+        qCDebug(logBackend) << "Creating new LogBackend instance";
         m_staticbackend = new LogBackend(parent);
     }
 
+    qCDebug(logBackend) << "Returning LogBackend instance";
     return m_staticbackend;
 }
 
 LogBackend::~LogBackend()
 {
-
+    qCDebug(logBackend) << "Destroying LogBackend instance";
 }
 
 LogBackend::LogBackend(QObject *parent) : QObject(parent)
@@ -60,7 +63,10 @@ LogBackend::LogBackend(QObject *parent) : QObject(parent)
     getLogTypes();
 
     m_cmdWorkDir = QDir::currentPath();
+    qCInfo(logBackend) << "Set command working directory to:" << m_cmdWorkDir;
+    
     Utils::m_mapAuditType2EventType = LogSettings::instance()->loadAuditMap();
+    qCDebug(logBackend) << "Loaded audit type mapping";
 
     initConnections();
 }
@@ -143,8 +149,10 @@ void LogBackend::setCmdWorkDir(const QString &dirPath)
 
 int LogBackend::exportAllLogs(const QString &outDir)
 {
-    if(!getOutDirPath(outDir))
+    if(!getOutDirPath(outDir)) {
+        qCWarning(logBackend) << "Invalid output directory:" << outDir;
         return -1;
+    }
 
     PERF_PRINT_BEGIN("POINT-05", "export all logs");
     qCInfo(logBackend) << "exporting all logs begin.";
@@ -189,8 +197,10 @@ int LogBackend::exportAllLogs(const QString &outDir)
 int LogBackend::exportTypeLogs(const QString &outDir, const QString &type)
 {
     // 输出目录有效性验证
-    if(!getOutDirPath(outDir))
+    if(!getOutDirPath(outDir)) {
+        qCWarning(logBackend) << "Invalid output directory:" << outDir;
         return -1;
+    }
 
     // 日志种类有效性验证
     QString error;
@@ -407,8 +417,10 @@ int LogBackend::exportTypeLogs(const QString &outDir, const QString &type)
 
 bool LogBackend::LogBackend::exportTypeLogsByCondition(const QString &outDir, const QString &type, const QString &period, const QString &condition, const QString &keyword)
 {
-    if (!getOutDirPath(outDir))
+    if (!getOutDirPath(outDir)) {
+        qCWarning(logBackend) << "Invalid output directory:" << outDir;
         return false;
+    }
 
     // 日志种类有效性验证
     QString error;
@@ -436,11 +448,15 @@ bool LogBackend::LogBackend::exportTypeLogsByCondition(const QString &outDir, co
 
 int LogBackend::exportAppLogs(const QString &outDir, const QString &appName)
 {
-    if(!getOutDirPath(outDir))
+    if(!getOutDirPath(outDir)) {
+        qCWarning(logBackend) << "Invalid output directory:" << outDir;
         return -1;
+    }
 
-    if (appName.isEmpty())
+    if (appName.isEmpty()) {
+        qCWarning(logBackend) << "Empty app name provided";
         return -1;
+    }
 
     // 先查找是否有该应用相关日志配置
     if (!LogApplicationHelper::instance()->isAppLogConfigExist(appName)) {
@@ -448,7 +464,7 @@ int LogBackend::exportAppLogs(const QString &outDir, const QString &appName)
         return -1;
     }
 
-    qCInfo(logBackend) << QString("exporting %1 logs...").arg(appName);
+    qCInfo(logBackend) << "Exporting logs for app:" << appName;
 
     QString categoryOutPath = QString("%1/%2").arg(m_outPath).arg(appName);
 
@@ -600,10 +616,10 @@ QStringList LogBackend::getLogTypes()
         m_logTypes.push_back(CUSTOM_TREE_DATA);
     }
 
-    // 审计日志文件存在，才加载和显示审计日志模块（审计日志文件需要root权限访问，因此在service服务中判断审计日志文件是否存在）
-    if (DLDBusHandler::instance(qApp)->isFileExist(AUDIT_TREE_DATA)) {
-        m_logTypes.push_back(AUDIT_TREE_DATA);
-    }
+    //audit
+    m_logTypes.push_back(AUDIT_TREE_DATA);
+
+    DLDBusHandler::instance(qApp)->whiteListOutPaths();
 
     return m_logTypes;
 }
@@ -2780,28 +2796,21 @@ void LogBackend::parseCoredumpDetailInfo(QList<LOG_MSG_COREDUMP> &list)
             QString outInfoByte;
             // get maps info
             const QString &corePath = QDir::tempPath() + QString("/%1.dump").arg(QFileInfo(data.storagePath).fileName());
-            DLDBusHandler::instance()->readLog(QString("coredumpctl dump %1 -o %2").arg(data.pid).arg(corePath));
-            outInfoByte = DLDBusHandler::instance()->readLog(QString("readelf -n %1").arg(corePath));
+            DLDBusHandler::instance()->executeCmd(QString("coredumpctl dump %1 -o %2").arg(data.pid).arg(corePath));
+            outInfoByte = DLDBusHandler::instance()->executeCmd(QString("readelf -n %1").arg(corePath));
 
             data.maps = outInfoByte;
 
             // 获取二进制文件信息
-            process.start("/bin/bash", QStringList() << "-c" << QString("file %1").arg(data.exe));
-            process.waitForFinished(-1);
-            outInfoByte = process.readAllStandardOutput();
+            outInfoByte = Utils::executeCmd("file", QStringList() << data.exe);
             if (!outInfoByte.isEmpty())
                 data.binaryInfo = outInfoByte;
-
             // 获取包名
-            process.start("/bin/bash", QStringList() << "-c" << QString("dpkg -S %1").arg(data.exe));
-            process.waitForFinished(-1);
-            outInfoByte = process.readAllStandardOutput();
+            outInfoByte = Utils::executeCmd("dpkg", QStringList() << "-S" << data.exe);
             // 获取版本号
             if (!outInfoByte.isEmpty()) {
                 QString str = outInfoByte;
-                process.start("/bin/bash", QStringList() << "-c" << QString("dpkg-query --show %1").arg(str.split(":").first()));
-                process.waitForFinished(-1);
-                outInfoByte = process.readAllStandardOutput();
+                outInfoByte = Utils::executeCmd("dpkg-query", QStringList() << "--show" << str.split(":").first());
                 if (!outInfoByte.isEmpty()) {
                     data.packgeVersion = QString(outInfoByte).simplified();
                 }
