@@ -6,6 +6,7 @@
 #include "logsettings.h"
 #include "dbusmanager.h"
 #include "dbusproxy/dldbushandler.h"
+#include "qtcompat.h"
 
 #include <math.h>
 #include <pwd.h>
@@ -29,7 +30,11 @@
 #include <QLoggingCategory>
 #include <QDBusInterface>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <polkit-qt5-1/PolkitQt1/Authority>
+#else
+#include <polkit-qt6-1/PolkitQt1/Authority>
+#endif
 using namespace PolkitQt1;
 
 #ifdef QT_DEBUG
@@ -59,6 +64,7 @@ const int COREDUMP_TIME_THRESHOLD = 3;
 Utils::Utils(QObject *parent)
     : QObject(parent)
 {
+    qCDebug(logUtils) << "Utils constructor";
 }
 
 Utils::~Utils()
@@ -67,11 +73,15 @@ Utils::~Utils()
 
 QString Utils::getQssContent(const QString &filePath)
 {
+    qCDebug(logUtils) << "Loading QSS content from:" << filePath;
     QFile file(filePath);
     QString qss;
 
     if (file.open(QIODevice::ReadOnly)) {
         qss = file.readAll();
+        qCDebug(logUtils) << "Successfully loaded QSS content";
+    } else {
+        qCWarning(logUtils) << "Failed to open QSS file:" << filePath << file.errorString();
     }
 
     return qss;
@@ -95,14 +105,13 @@ QString Utils::getAppDataPath()
 
 bool Utils::isFontMimeType(const QString &filePath)
 {
+    qCDebug(logUtils) << "Checking font MIME type for:" << filePath;
     const QString mimeName = QMimeDatabase().mimeTypeForFile(filePath).name();
-    ;
-
-    if (mimeName.startsWith("font/") || mimeName.startsWith("application/x-font")) {
-        return true;
-    }
-
-    return false;
+    
+    bool isFont = mimeName.startsWith("font/") || mimeName.startsWith("application/x-font");
+    qCDebug(logUtils) << "MIME type:" << mimeName << "isFont:" << isFont;
+    
+    return isFont;
 }
 
 bool Utils::isTextFileType(const QString &filePath)
@@ -175,8 +184,8 @@ QString Utils::getReplaceColorStr(const char *d)
     QByteArray byteChar(d);
     byteChar = replaceEmptyByteArray(byteChar);
     QString d_str = QString(byteChar);
-    d_str.replace(QRegExp("\\x1B\\[\\d+(;\\d+){0,2}m"), "");
-    d_str.replace(QRegExp("\\002"), "");
+    d_str.replace(REG_EXP("\\x1B\\[\\d+(;\\d+){0,2}m"), "");
+    d_str.replace(REG_EXP("\\002"), "");
     return  d_str;
 }
 
@@ -209,15 +218,21 @@ Utils::CommandErrorType Utils::isErroCommand(const QString &str)
 
 bool Utils::checkAndDeleteDir(const QString &iFilePath)
 {
+    qCDebug(logUtils) << "Checking and deleting directory/file:" << iFilePath;
     QFileInfo tempFileInfo(iFilePath);
 
     if (tempFileInfo.isDir()) {
-        deleteDir(iFilePath);
-        return true;
+        bool result = deleteDir(iFilePath);
+        qCDebug(logUtils) << "Directory deletion result:" << result;
+        return result;
     } else if (tempFileInfo.isFile()) {
         QFile deleteFile(iFilePath);
-        return deleteFile.remove();
+        bool result = deleteFile.remove();
+        qCDebug(logUtils) << "File deletion result:" << result;
+        return result;
     }
+    
+    qCWarning(logUtils) << "Path is neither directory nor file:" << iFilePath;
     return false;
 }
 
@@ -258,7 +273,7 @@ bool Utils::deleteDir(const QString &iFilePath)
 
 void Utils::replaceColorfulFont(QString *iStr)
 {
-    iStr->replace(QRegExp("[[0-9]{1,2}m"), "");
+    iStr->replace(REG_EXP("[[0-9]{1,2}m"), "");
 }
 
 bool Utils::isWayland()
@@ -304,11 +319,15 @@ QString Utils::mkMutiDir(const QString &path)
 
 bool Utils::checkAuthorization(const QString &actionId, qint64 applicationPid)
 {
+    qCDebug(logUtils) << "Checking authorization for action:" << actionId << "pid:" << applicationPid;
     Authority::Result result;
 
     result = Authority::instance()->checkAuthorizationSync(actionId, UnixProcessSubject(applicationPid),
                                                            Authority::AllowUserInteraction);
-    return result == Authority::Yes ? true : false;
+    bool authorized = result == Authority::Yes;
+    qCDebug(logUtils) << "Authorization result:" << authorized;
+    
+    return authorized;
 }
 
 QString Utils::osVersion()
@@ -318,10 +337,16 @@ QString Utils::osVersion()
     unlock->waitForFinished();
     auto output = unlock->readAllStandardOutput();
     auto str = QString::fromUtf8(output);
-    QRegExp re("\t.+\n");
+    REG_EXP re("\t.+\n");
     QString osVerStr;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (re.indexIn(str) > -1) {
         auto result = re.cap(0);
+#else
+    QRegularExpressionMatch match = re.match(str);
+    if (match.hasMatch()) {
+        auto result = match.captured(0);
+#endif
         osVerStr = result.remove(0, 1).remove(result.size() - 1, 1);
     }
     unlock->deleteLater();
@@ -386,65 +411,25 @@ QString Utils::getCurrentUserName()
     return pwd->pw_name;
 }
 
-bool Utils::isValidUserName(const QString &userName)
-{
-    bool bValidUserName = false;
-    QDBusInterface interface("com.deepin.daemon.Accounts", "/com/deepin/daemon/Accounts", "com.deepin.daemon.Accounts", QDBusConnection::systemBus());
-    QStringList userList = qvariant_cast< QStringList >(interface.property("UserList"));
-    for (auto strUser : userList) {
-        uint uid = strUser.mid(strUser.lastIndexOf("User") + 4).toUInt();
-        QString tempUserName = getUserNamebyUID(uid);
-        if(tempUserName == userName) {
-            bValidUserName = true;
-            break;
-        }
-    }
-
-    return bValidUserName;
-}
-
 bool Utils::isCoredumpctlExist()
 {
+    qCDebug(logUtils) << "Checking if coredumpctl exists";
     bool isCoredumpctlExist = false;
     QDir dir("/usr/bin");
     QStringList list = dir.entryList(QStringList() << (QString("coredumpctl") + "*"), QDir::NoDotAndDotDot | QDir::Files);
+    
     for (int i = 0; i < list.count(); i++) {
         if("coredumpctl" == list[i]) {
             isCoredumpctlExist = true;
+            qCDebug(logUtils) << "Found coredumpctl";
             break;
         }
     }
+    
+    qCDebug(logUtils) << "coredumpctl exists:" << isCoredumpctlExist;
     return isCoredumpctlExist;
 }
 
-QString Utils::getHomePath(const QString &userName)
-{
-    QString uName("");
-    if (!userName.isEmpty())
-        uName = userName;
-    else
-        uName = getCurrentUserName();
-
-    QString homePath = "";
-    if (isValidUserName(uName)) {
-        QProcess *unlock = new QProcess;
-        unlock->start("sh", QStringList() << "-c" << QString("cat /etc/passwd | grep %1").arg(uName));
-        unlock->waitForFinished();
-        auto output = unlock->readAllStandardOutput();
-        auto str = QString::fromUtf8(output);
-        homePath = str.mid(str.indexOf("::") + 2).split(":").first();
-    }
-
-    // 根据用户名获取家目录失败，默认采用QDir::homePath()作为homePath
-    QDir dir(homePath);
-    if (!dir.exists() || homePath.isEmpty())
-        homePath = QDir::homePath();
-
-    qCDebug(logUtils) << "userName: " << uName << "homePath:" << homePath;
-
-    return homePath;
-}
-
 QString Utils::appName(const QString &filePath)
 {
     QString ret;
@@ -474,16 +459,13 @@ void Utils::resetToNormalAuth(const QString &path)
     QFileInfo fi(path);
     if (!path.isEmpty() && fi.exists()) {
         qInfo() << "resetToNormalAuth: " << path;
-        QProcess procss;
+        QString tmpPath = path;
         if (fi.isDir())
-            procss.setWorkingDirectory(path);
+            tmpPath = path;
         else
-            procss.setWorkingDirectory(fi.absolutePath());
+            tmpPath = fi.absolutePath();
 
-        QStringList arg = {"-c"};
-        arg.append(QString("chmod -R 777 '%1'").arg(path));
-        procss.start("/bin/bash", arg);
-        procss.waitForFinished(-1);
+        executeCmd("chmod", QStringList() << "-R" << "777" << tmpPath);
     }
 }
 
@@ -491,13 +473,13 @@ QList<LOG_REPEAT_COREDUMP_INFO> Utils::countRepeatCoredumps(qint64 timeBegin, qi
 {
     QList<LOG_REPEAT_COREDUMP_INFO> result;
     QString data = DLDBusHandler::instance()->executeCmd("coredumpctl-list");
-    QStringList strList = data.split('\n', QString::SkipEmptyParts);
+    QStringList strList = data.split('\n', SKIP_EMPTY_PARTS);
     int total = 0;
     for (int i = strList.size() - 1; i >= 0; --i) {
         QString str = strList.at(i);
         if (str.trimmed().isEmpty())
             continue;
-        QStringList tmpList = str.split(" ", QString::SkipEmptyParts);
+        QStringList tmpList = str.split(" ", SKIP_EMPTY_PARTS);
         if (tmpList.count() < 10)
             continue;
 
@@ -591,6 +573,33 @@ void Utils::updateRepeatCoredumpExePaths(const QList<LOG_REPEAT_COREDUMP_INFO> &
     file.close();
 }
 
+static QByteArray processCmdWithArgs(const QString &cmdStr, const QString &workPath, const QStringList &args)
+{
+    QProcess process;
+    if (!workPath.isEmpty())
+        process.setWorkingDirectory(workPath);
+
+    process.setProgram(cmdStr);
+    process.setArguments(args);
+    process.setEnvironment({"LANG=en_US.UTF-8", "LANGUAGE=en_US"});
+    process.start();
+    // Wait for process to finish without timeout.
+    process.waitForFinished(-1);
+    QByteArray outPut = process.readAllStandardOutput();
+    int nExitCode = process.exitCode();
+    bool bRet = (process.exitStatus() == QProcess::NormalExit && nExitCode == 0);
+    if (!bRet) {
+        qDebug() << "run cmd error, caused by:" << process.errorString() << "output:" << outPut;
+        return QByteArray();
+    }
+    return outPut;
+}
+
+QByteArray Utils::executeCmd(const QString &cmdStr, const QStringList &args, const QString &workPath)
+{
+    return processCmdWithArgs(cmdStr, workPath,  args);
+}
+
 #ifdef DTKCORE_CLASS_DConfigFile
 LoggerRules::LoggerRules(QObject *parent)
     : QObject(parent), m_rules(""), m_config(nullptr) {
