@@ -7,6 +7,7 @@
 #include "ut_stuballthread.h"
 #include "../../3rdparty/DocxFactory/include/DocxFactory/WordProcessingMerger/WordProcessingMerger.h"
 #include <stub.h>
+#include "../../application/qtcompat.h"
 
 #include <DApplication>
 #include <DStandardItem>
@@ -63,16 +64,16 @@ public:
     //添加日志
     static void SetUpTestCase()
     {
-        qDebug() << "SetUpTestCase" << endl;
+        qDebug() << "SetUpTestCase" << ENDL;
     }
     static void TearDownTestCase()
     {
-        qDebug() << "TearDownTestCase" << endl;
+        qDebug() << "TearDownTestCase" << ENDL;
     }
     void SetUp() //TEST跑之前会执行SetUp
     {
         exportThread = new LogExportThread();
-        qDebug() << "SetUp" << endl;
+        qDebug() << "SetUp" << ENDL;
     }
     void TearDown() //TEST跑完之后会执行TearDown
     {
