@@ -1,27 +1,35 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="zh_CN">
 <context>
     <name>Action</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="188"/>
         <source>Display in file manager</source>
         <translation>在文件管理器中显示</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="489"/>
         <source>Clear log</source>
         <translation>清除日志</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="189"/>
         <source>Refresh</source>
         <translation>刷新</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="539"/>
         <source>Are you sure you want to clear the log?</source>
         <translation>您确定要清除该日志吗？</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="540"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="541"/>
         <source>Confirm</source>
         <translation>确定</translation>
     </message>
@@ -29,30 +37,37 @@
 <context>
     <name>Button</name>
     <message>
+        <location filename="../application/filtercontent.cpp" line="80"/>
         <source>All</source>
         <translation>全部</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="83"/>
         <source>Today</source>
         <translation>今天</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="86"/>
         <source>3 days</source>
         <translation>近三天</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="89"/>
         <source>1 week</source>
         <translation>近一周</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="92"/>
         <source>1 month</source>
         <translation>近一个月</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="95"/>
         <source>3 months</source>
         <translation>近三个月</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="224"/>
         <source>Export</source>
         <comment>button</comment>
         <translation>导 出</translation>
@@ -61,82 +76,102 @@
 <context>
     <name>ComboBox</name>
     <message>
+        <location filename="../application/filtercontent.cpp" line="120"/>
         <source>All</source>
         <translation>全部</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="121"/>
         <source>Emergency</source>
         <translation>紧急</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="122"/>
         <source>Alert</source>
         <translation>严重警告</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="123"/>
         <source>Critical</source>
         <translation>严重</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="124"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="125"/>
         <source>Warning</source>
         <translation>警告</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="126"/>
         <source>Notice</source>
         <translation>注意</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="127"/>
         <source>Info</source>
         <translation>信息</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="128"/>
         <source>Debug</source>
         <translation>调试</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="198"/>
         <source>Login</source>
         <translation>登录</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="199"/>
         <source>Boot</source>
         <translation>开机</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="200"/>
         <source>Shutdown</source>
         <translation>关机</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="142"/>
         <source>Super critical</source>
         <translation>非常严重</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="148"/>
         <source>Trace</source>
         <translation>跟踪</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="212"/>
         <source>Identity authentication</source>
         <translation>身份鉴别</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="213"/>
         <source>Discretionary Access Control</source>
         <translation>自主访问控制</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="214"/>
         <source>Mandatory access control</source>
         <translation>强制访问控制</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="215"/>
         <source>Remote</source>
         <translation>远程连接</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="216"/>
         <source>Document audit</source>
         <translation>文件审计</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="217"/>
         <source>Other</source>
         <translation>其他</translation>
     </message>
@@ -144,10 +179,12 @@
 <context>
     <name>DisplayContent</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1800"/>
         <source>zip(*.zip)</source>
-        <translation type="unfinished"/>
+        <translation>解压（*.zip）</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1794"/>
         <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
         <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
     </message>
@@ -155,10 +192,12 @@
 <context>
     <name>ExportDlg</name>
     <message>
+        <location filename="../application/exportprogressdlg.cpp" line="35"/>
         <source>Exporting...</source>
         <translation>正在导出...</translation>
     </message>
     <message>
+        <location filename="../application/exportprogressdlg.cpp" line="58"/>
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
@@ -166,14 +205,17 @@
 <context>
     <name>ExportMessage</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3257"/>
         <source>Export successful</source>
         <translation>导出成功</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3260"/>
         <source>Export failed</source>
         <translation>导出失败</translation>
     </message>
     <message>
+        <location filename="../application/logbackend.cpp" line="1763"/>
         <source>The export directory is not available. Please choose another directory for the export operation.</source>
         <translation>导出目录不可用，请选择其他目录进行导出操作。</translation>
     </message>
@@ -181,6 +223,7 @@
 <context>
     <name>File</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1792"/>
         <source>Export File</source>
         <translation>导出文件</translation>
     </message>
@@ -188,58 +231,72 @@
 <context>
     <name>Label</name>
     <message>
+        <location filename="../application/filtercontent.cpp" line="76"/>
         <source>Period:</source>
         <translation>周期：</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="114"/>
         <source>Level:  </source>
         <translation>级别：</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="180"/>
         <source>Status:</source>
         <translation>状态：</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="193"/>
         <source>Event Type:</source>
         <translation>事件类型：</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="132"/>
         <source>User:</source>
         <translation>主机名：</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="134"/>
         <source>PID:</source>
         <translation>进程号：</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="138"/>
         <source>Action:</source>
         <translation>动作：</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="143"/>
         <source>Username:</source>
         <translation>用户名：</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="469"/>
         <source>Boot record</source>
         <translation>开机记录</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="471"/>
         <source>Shutdown record</source>
         <translation>关机记录</translation>
     </message>
     <message>
+        <location filename="../application/logdetailinfowidget.cpp" line="474"/>
         <source>Login record</source>
         <translation>登录信息</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="208"/>
         <source>Audit Type:</source>
         <translation>审计类型：</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="155"/>
         <source>Application:</source>
         <translation>应用：</translation>
     </message>
     <message>
+        <location filename="../application/filtercontent.cpp" line="167"/>
         <source>Submodule:</source>
         <translation>子模块：</translation>
     </message>
@@ -247,42 +304,52 @@
 <context>
     <name>Level</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="201"/>
         <source>Warning</source>
         <translation>警告</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="202"/>
         <source>Debug</source>
         <translation>调试</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="203"/>
         <source>Info</source>
         <translation>信息</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="204"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="208"/>
         <source>Emergency</source>
         <translation>紧急</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="209"/>
         <source>Alert</source>
         <translation>严重警告</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="210"/>
         <source>Critical</source>
         <translation>严重</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="213"/>
         <source>Notice</source>
         <translation>注意</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="220"/>
         <source>Trace</source>
         <translation>跟踪</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="226"/>
         <source>Super critical</source>
         <translation>非常严重</translation>
     </message>
@@ -290,6 +357,7 @@
 <context>
     <name>LogAuthThread</name>
     <message>
+        <location filename="../application/logauththread.cpp" line="529"/>
         <source>Log file is empty</source>
         <translation>日志文件为空</translation>
     </message>
@@ -297,10 +365,12 @@
 <context>
     <name>Main</name>
     <message>
+        <location filename="../application/main.cpp" line="329"/>
         <source>Log Viewer</source>
         <translation>日志收集工具</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="332"/>
         <source>Log Viewer is a useful tool for viewing system logs.</source>
         <translation>日志收集工具是一款查看系统日志的小工具。</translation>
     </message>
@@ -308,10 +378,12 @@
 <context>
     <name>SearchBar</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="120"/>
         <source>No search results</source>
         <translation>无搜索结果</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="109"/>
         <source>Search</source>
         <translation>搜索</translation>
     </message>
@@ -319,109 +391,135 @@
 <context>
     <name>Table</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="563"/>
         <source>Level</source>
         <translation>级别</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="564"/>
         <source>Process</source>
         <translation>进程</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="565"/>
         <source>Date and Time</source>
         <translation>时间</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="566"/>
         <source>Info</source>
         <translation>信息</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="567"/>
         <source>User</source>
         <translation>主机名</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="568"/>
         <source>PID</source>
         <translation>进程号</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="953"/>
         <source>Source</source>
         <translation>来源</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="669"/>
         <source>Action</source>
         <translation>动作</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3374"/>
         <source>Status</source>
         <translation>状态</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1140"/>
         <source>Event Type</source>
         <translation>事件类型</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1141"/>
         <source>Username</source>
         <translation>用户名</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="897"/>
         <source>Level:</source>
         <translation>级别：</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="898"/>
         <source>Process:</source>
         <translation>进程：</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="899"/>
         <source>Date and Time:</source>
         <translation>时间：</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="901"/>
         <source>Info:</source>
         <translation>信息：</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="902"/>
         <source>Null</source>
         <translation>Null</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="906"/>
         <source>User:</source>
         <translation>主机名：</translation>
     </message>
     <message>
+        <location filename="../application/logexportthread.cpp" line="907"/>
         <source>PID:</source>
         <translation>进程号：</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3532"/>
         <source>File Name</source>
         <translation>文件名称</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3533"/>
         <source>Time Modified</source>
         <translation>修改日期</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3741"/>
         <source>SIG</source>
         <translation>崩溃信号</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3745"/>
         <source>EXE</source>
         <translation>进程</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3743"/>
         <source>Core File</source>
         <translation>核心文件</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="3744"/>
         <source>User Name </source>
         <translation>用户</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1009"/>
         <source>Offset</source>
-        <translation>进程</translation>
+        <translation>偏移量</translation>
     </message>
 </context>
 <context>
     <name>Tbble</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="1142"/>
         <source>Date and Time</source>
         <translation>时间</translation>
     </message>
@@ -429,54 +527,67 @@
 <context>
     <name>Tree</name>
     <message>
+        <location filename="../application/loglistview.cpp" line="171"/>
         <source>System Log</source>
         <translation>系统日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="182"/>
         <source>Kernel Log</source>
         <translation>内核日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="203"/>
         <source>Boot Log</source>
         <translation>启动日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="232"/>
         <source>dpkg Log</source>
         <translation>dpkg日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="244"/>
         <source>Kwin Log</source>
         <translation>Kwin日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="253"/>
         <source>Xorg Log</source>
         <translation>Xorg日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="265"/>
         <source>Application Log</source>
         <translation>应用日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="290"/>
         <source>Boot-Shutdown Event</source>
         <translation>开关机事件</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="222"/>
         <source>dnf Log</source>
         <translation>dnf日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="303"/>
         <source>Other Log</source>
         <translation>其它日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="339"/>
         <source>Custom Log</source>
         <translation>自定义日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="319"/>
         <source>Audit Log</source>
         <translation>审计日志</translation>
     </message>
     <message>
+        <location filename="../application/loglistview.cpp" line="278"/>
         <source>Coredump Log</source>
         <translation>崩溃日志</translation>
     </message>
@@ -484,6 +595,7 @@
 <context>
     <name>Waring</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="133"/>
         <source>Unable to obtain crash information, please install systemd-coredump.</source>
         <translation>无法获取崩溃信息，请安装 systemd-coredump。</translation>
     </message>
@@ -491,91 +603,117 @@
 <context>
     <name>Warning</name>
     <message>
+        <location filename="../application/displaycontent.cpp" line="139"/>
         <source>You do not have permission to view it</source>
         <translation>无权限查看</translation>
     </message>
     <message>
+        <location filename="../application/displaycontent.cpp" line="127"/>
         <source>Security level for the current system: high
  audit only administrators can view the audit log</source>
         <translation>当前系统安全等级为：高
 仅审计管理员可查看审计日志</translation>
     </message>
+    <message>
+        <location filename="../application/displaycontent.cpp" line="3216"/>
+        <source>Audit log is not exist.</source>
+        <translation>审计日志不存在。</translation>
+    </message>
 </context>
 <context>
     <name>main</name>
     <message>
+        <location filename="../application/main.cpp" line="67"/>
         <source>Export logs to the specified path</source>
         <translation>导出日志到指定目录</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="67"/>
         <source>PATH</source>
         <translation>导出路径</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="68"/>
         <source>Export logs of specified types</source>
         <translation>按日志种类导出日志</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="68"/>
         <source>TYPE</source>
         <translation>日志种类</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="69"/>
         <source>Export logs of specified self-developed applications</source>
         <translation>按自研应用导出日志</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="69"/>
         <source>SELF APPNAME</source>
         <translation>自研应用名称</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="70"/>
         <source>Export logs within a specified time period</source>
         <translation>按时间周期导出日志</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="70"/>
         <source>PERIOD</source>
         <translation>周期</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="71"/>
         <source>Export logs within a specified debug level</source>
         <translation>按调试级别导出日志</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="71"/>
         <source>LEVEL</source>
         <translation>调试级别</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="72"/>
         <source>BOOT STATUS</source>
         <translation>启动状态</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="72"/>
         <source>Export boot(no-klu) logs within a specified status</source>
         <translation>按状态导出启动日志(klu)</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="73"/>
         <source>Export boot-shutdown-event or audit logs within a specified event type</source>
         <translation>按事件类型导出开关机事件/审计日志</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="73"/>
         <source>EVENT TYPE</source>
         <translation>事件类型</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="74"/>
         <source>Export logs based on keywords search results</source>
         <translation>按关键词导出日志</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="74"/>
         <source>KEY WORD</source>
         <translation>关键词</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="76"/>
         <source>Report coredump informations.</source>
         <translation>上报崩溃埋点信息</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="75"/>
         <source>Export logs based on app submodel</source>
         <translation>按子模块导出应用日志</translation>
     </message>
     <message>
+        <location filename="../application/main.cpp" line="75"/>
         <source>SUBMODULE</source>
         <translation>子模块</translation>
     </message>
@@ -583,32 +721,39 @@
 <context>
     <name>titlebar</name>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="202"/>
         <source>Refresh interval</source>
         <translation>刷新频率</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="204"/>
         <source>10 sec</source>
         <translation>每10秒</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="205"/>
         <source>1 min</source>
         <translation>每1分钟</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="206"/>
         <source>5 min</source>
         <translation>5分钟</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="207"/>
         <source>No refresh</source>
         <translation>不刷新</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="234"/>
         <source>Export All</source>
         <translation>全部导出</translation>
     </message>
     <message>
+        <location filename="../application/logcollectormain.cpp" line="240"/>
         <source>Refresh Now</source>
         <translation>立即刷新</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
